@@ -48,6 +48,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import constructs
@@ -78,6 +80,10 @@ class Redis(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Redis.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = RedisOptions(labels=labels, replicas=replicas)
 
         jsii.create(self.__class__, self, [scope, id, options])
@@ -119,6 +125,10 @@ class RedisOptions:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RedisOptions.__init__)
+            check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
+            check_type(argname="argument replicas", value=replicas, expected_type=type_hints["replicas"])
         self._values: typing.Dict[str, typing.Any] = {}
         if labels is not None:
             self._values["labels"] = labels
